@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.009002'; # VERSION
+our $VERSION = '0.010000'; # VERSION
 
 1;
 
@@ -21,7 +21,7 @@ Business::CyberSource - Perl interface to the CyberSource Simple Order SOAP API
 
 =head1 VERSION
 
-version 0.009002
+version 0.010000
 
 =head1 DESCRIPTION
 
@@ -86,13 +86,22 @@ A test credit card number provided by your your credit card processor
 
 =head1 EXAMPLE
 
+In the example, C<carp> means you should log something C<Dumper> means you should
+log it with lots of detail. L<Safe::Isa> is used because you should either use
+it or check for C<blessed> it is always possible that somewhere in the stack
+someone is using C<die> on a string.
+
 	use 5.010;
 	use Carp;
 	use Try::Tiny;
+	use Safe::Isa;
+	use Data::Printer alias => 'Dumper';
 
 	use Business::CyberSource::Client;
 	use Business::CyberSource::Request::Authorization;
 	use Business::CyberSource::Request::Capture;
+	# exception namepsace
+	my $e_ns = 'Business::CyberSource::Exception';
 
 	my $client = Business::CyberSource::Client->new({
 		user  => 'Merchant ID',
@@ -131,7 +140,22 @@ A test credit card number provided by your your credit card processor
 			});
 	}
 	catch {
-		carp $_;
+		my $e = $_;
+		sif ( $e->$_does('Business::CyberSource::Response::Role::Base') )
+			carp $e->reason_code . $e->reason_text;
+		}
+		elsif ( $e->$_isa( $e_ns . '::SOAPFault'  ) ) {
+			carp $e->faultcode . $e->faultstring;
+		}
+		elsif ( $e->$_isa( $e_ns ) || $e->$_isa( 'Moose::Exception' ) ) {
+			Dumper( $e );
+			## probably your payload was bad, check type more
+			## specifically and feed good error messages to your
+			## customer
+		}
+		else { # probably a coding error
+			Dumper( $e );
+		}
 	};
 	return unless $auth_request;
 
@@ -165,7 +189,22 @@ A test credit card number provided by your your credit card processor
 			$capture_response = $client->submit( $capture_request );
 		}
 		catch {
-			carp $_;
+			my $e = $_;
+			if ( $e->$_does('Business::CyberSource::Response::Role::Base') )
+				carp $e->reason_code . $e->reason_text;
+			}
+			elsif ( $e->$_isa( $e_ns . '::SOAPFault'  ) ) {
+				carp $e->faultcode . $e->faultstring;
+			}
+			elsif ( $e->$_isa( $e_ns ) || $e->$_isa( 'Moose::Exception' ) ) {
+				Dumper( $e );
+				## probably your payload was bad, check type more
+				## specifically and feed good error messages to your
+				## customer
+			}
+			else { # probably a coding error
+				Dumper( $e );
+			}
 		};
 		return unless $capture_response;
 
@@ -221,17 +260,27 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
 
 Carl Carstenson <ccarstenson@hostgator.com>
 
+=item *
+
+Robert Stone <robertstone@hostgator.com>
+
+=back
+
 =head1 AUTHOR
 
 Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2014 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
