@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.009002'; # VERSION
+our $VERSION = '0.010000'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Message';
@@ -12,7 +12,6 @@ with qw(
 	MooseX::RemoteHelper::CompositeSerialization
 );
 
-use MooseX::Types::Moose       qw( ArrayRef );
 use MooseX::Types::CyberSource qw( PurchaseTotals Service Items );
 
 use Module::Runtime  qw( use_module );
@@ -23,7 +22,8 @@ before serialize => sub { ## no critic qw( Subroutines::RequireFinalReturn )
 	my $self = shift;
 
 	if ( ! $self->has_total && ( ! $self->has_items || $self->items_is_empty ) ) {
-		confess 'you must define either items or total';
+		die ## no critic ( ErrorHandling::RequireCarping )
+			use_module('Business::CyberSource::Exception::ItemsOrTotal')->new;
 	}
 };
 
@@ -107,7 +107,7 @@ has items => (
 	},
 );
 
-has '+trace' => (
+has '+http_trace' => (
 	is        => 'rw',
 	init_arg  => undef
 );
@@ -129,7 +129,7 @@ Business::CyberSource::Request - Abstract Request Class
 
 =head1 VERSION
 
-version 0.009002
+version 0.010000
 
 =head1 DESCRIPTION
 
@@ -225,7 +225,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2014 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
