@@ -3,16 +3,20 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.009002'; # VERSION
+our $VERSION = '0.010000'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request::Credit';
 
 sub BUILD { ## no critic ( Subroutines::RequireFinalReturn )
 	my $self = shift;
-	confess 'a Follow On Credit should set a request_id'
-		unless $self->service->has_request_id
-		;
+	die ## no critic ( ErrorHandling::RequireCarping )
+		use_module('Business::CyberSource::Exception::AttributeIsRequiredNotToBeSet')
+		->new(
+			attribute_name => 'request_id',
+			class_name     => __PACKAGE__,
+			message        => 'a Follow On Credit should set a request_id',
+		) unless $self->service->has_request_id;
 };
 
 __PACKAGE__->meta->make_immutable;
@@ -32,7 +36,7 @@ Business::CyberSource::Request::FollowOnCredit - CyberSource Credit Request Obje
 
 =head1 VERSION
 
-version 0.009002
+version 0.010000
 
 =head1 SYNOPSIS
 
@@ -72,7 +76,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2014 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
