@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.009002'; # VERSION
+our $VERSION = '0.010000'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request::Credit';
@@ -14,9 +14,13 @@ with qw(
 
 sub BUILD { ## no critic ( Subroutines::RequireFinalReturn )
 	my $self = shift;
-	confess 'a Stand Alone Credit should not set a request_id'
-		if $self->service->has_request_id
-		;
+	die ## no critic ( ErrorHandling::RequireCarping )
+		use_module('Business::CyberSource::Exception::AttributeIsRequiredNotToBeSet')
+		->new(
+			attribute_name => 'request_id',
+			class_name     => __PACKAGE__,
+			message        => 'a Stand Alone Credit should not set a request_id'
+		) if $self->service->has_request_id;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -36,7 +40,7 @@ Business::CyberSource::Request::StandAloneCredit - CyberSource Credit Request Ob
 
 =head1 VERSION
 
-version 0.009002
+version 0.010000
 
 =head1 SYNOPSIS
 
@@ -100,7 +104,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2014 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
